==> groovy-sandbox-1.6-sources.jar: org/kohsuke/groovy/sandbox/ScopeTrackingClassCodeExpressionTransformer.java <==
package org.kohsuke.groovy.sandbox;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public abstract class ScopeTrackingClassCodeExpressionTransformer
  extends org.codehaus.groovy.ast.ClassCodeExpressionTransformer  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  boolean isLocalVariable(java.lang.String name) { return false;}
@java.lang.Override() public  void visitMethod(org.codehaus.groovy.ast.MethodNode node) { }
protected  void withVarScope(groovy.lang.Closure body) { }
@java.lang.Override() public  void visitBlockStatement(org.codehaus.groovy.ast.stmt.BlockStatement block) { }
@java.lang.Override() public  void visitDoWhileLoop(org.codehaus.groovy.ast.stmt.DoWhileStatement loop) { }
@java.lang.Override() public  void visitForLoop(org.codehaus.groovy.ast.stmt.ForStatement forLoop) { }
@java.lang.Override() public  void visitIfElse(org.codehaus.groovy.ast.stmt.IfStatement ifElse) { }
@java.lang.Override() public  void visitSwitch(org.codehaus.groovy.ast.stmt.SwitchStatement statement) { }
@java.lang.Override() public  void visitSynchronizedStatement(org.codehaus.groovy.ast.stmt.SynchronizedStatement sync) { }
@java.lang.Override() public  void visitTryCatchFinally(org.codehaus.groovy.ast.stmt.TryCatchStatement statement) { }
@java.lang.Override() public  void visitWhileLoop(org.codehaus.groovy.ast.stmt.WhileStatement loop) { }
@java.lang.Override() public  void visitClosureExpression(org.codehaus.groovy.ast.expr.ClosureExpression expression) { }
public  void handleDeclarations(org.codehaus.groovy.ast.expr.DeclarationExpression exp) { }
public  java.lang.Object declareVariable(org.codehaus.groovy.ast.Variable exp) { return null;}
}

==> groovy-sandbox-1.8-sources.jar: org/kohsuke/groovy/sandbox/ScopeTrackingClassCodeExpressionTransformer.java <==
package org.kohsuke.groovy.sandbox;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public abstract class ScopeTrackingClassCodeExpressionTransformer
  extends org.codehaus.groovy.ast.ClassCodeExpressionTransformer  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  boolean isLocalVariable(java.lang.String name) { return false;}
@java.lang.Override() public  void visitMethod(org.codehaus.groovy.ast.MethodNode node) { }
protected  void withVarScope(groovy.lang.Closure body) { }
@java.lang.Override() public  void visitBlockStatement(org.codehaus.groovy.ast.stmt.BlockStatement block) { }
@java.lang.Override() public  void visitDoWhileLoop(org.codehaus.groovy.ast.stmt.DoWhileStatement loop) { }
@java.lang.Override() public  void visitForLoop(org.codehaus.groovy.ast.stmt.ForStatement forLoop) { }
@java.lang.Override() public  void visitIfElse(org.codehaus.groovy.ast.stmt.IfStatement ifElse) { }
@java.lang.Override() public  void visitSwitch(org.codehaus.groovy.ast.stmt.SwitchStatement statement) { }
@java.lang.Override() public  void visitSynchronizedStatement(org.codehaus.groovy.ast.stmt.SynchronizedStatement sync) { }
@java.lang.Override() public  void visitTryCatchFinally(org.codehaus.groovy.ast.stmt.TryCatchStatement statement) { }
@java.lang.Override() public  void visitCatchStatement(org.codehaus.groovy.ast.stmt.CatchStatement statement) { }
@java.lang.Override() public  void visitWhileLoop(org.codehaus.groovy.ast.stmt.WhileStatement loop) { }
@java.lang.Override() public  void visitClosureExpression(org.codehaus.groovy.ast.expr.ClosureExpression expression) { }
public  void handleDeclarations(org.codehaus.groovy.ast.expr.DeclarationExpression exp) { }
public  java.lang.Object declareVariable(org.codehaus.groovy.ast.Variable exp) { return null;}
}
